@@ -180,16 +180,21 @@ class RFStream(Stream):
         for tr in self:
             tr.stats.phase = value
 
-    def write(self, filename, format, **kwargs):
+    def write(self, filename, format, sh_compat=False, **kwargs):
         """
         Save stream to file including format specific headers.
 
         See `Stream.write() <obspy.core.stream.Stream.write>` in ObsPy.
+
+        :param sh_compat: Ensure files in Q format can be read with
+            SeismicHandler (default: False). If set to True the COMMENT field
+            will be deleted which might result in loss of some metadata.
+            (see issue #37).
         """
         if len(self) == 0:
             return
         for tr in self:
-            tr._write_format_specific_header(format)
+            tr._write_format_specific_header(format, sh_compat=sh_compat)
             if format.upper() == 'Q':
                 tr.stats.station = tr.id
         if format.upper() == 'H5':
@@ -277,11 +282,11 @@ class RFStream(Stream):
             method with the angles given by the back_azimuth and inclination
             attributes of the traces stats objects. You can set these to your
             needs or let them be computed by :func:`~rf.rfstream.rfstats`.
-        :param deconvolve: 'time', 'freq', 'iter', or 'multi' for time domain
-            water level, frequency domain water level, time domain iterative, or
-            frequency domain multitaper deconvolution using the stream's
-            `deconvolve()`
-            method. See `~.deconvolve.deconvolve()`,
+        :param deconvolve: 'time', 'waterlevel', 'iterative' or 'multitaper'
+            for time domain damped, frequency domain water level,
+            time domain iterative, or frequency domain multitaper
+            deconvolution using the stream's `deconvolve()` method.
+            See `~.deconvolve.deconvolve()`,
             `.deconv_time()`, `.deconv_waterlevel()`,
             `.deconv_iterative()`, and `.deconv_multitaper()`
             for further documentation.
@@ -466,7 +471,7 @@ class RFTrace(Trace):
         super(RFTrace, self).__init__(data=data, header=header)
         st = self.stats
         if ('_format'in st and st._format.upper() == 'Q' and
-                st.station.count('.') > 0):
+                st.station.count('.') > 1):
             st.network, st.station, st.location = st.station.split('.')[:3]
         self._read_format_specific_header()
 
@@ -527,10 +532,7 @@ class RFTrace(Trace):
         except KeyError:
             # file format is H5 or not supported
             return
-        read_comment = False
         for head, head_format in header_map:
-            if format == 'sh' and read_comment:
-                continue
             try:
                 value = st[format][head_format]
             except KeyError:
@@ -539,7 +541,10 @@ class RFTrace(Trace):
                 if format == 'sac' and '-12345' in str(value):
                     pass
                 elif format == 'sh' and head_format == 'COMMENT':
-                    st.update(json.loads(value))
+                    try:
+                        st.update(json.loads(value))
+                    except json.JSONDecodeError:
+                        pass
                     continue
                 else:
                     st[head] = value
@@ -549,7 +554,7 @@ class RFTrace(Trace):
             except KeyError:
                 pass
 
-    def _write_format_specific_header(self, format):
+    def _write_format_specific_header(self, format, sh_compat=False):
         st = self.stats
         format = format.lower()
         if format == 'q':
@@ -584,15 +589,18 @@ class RFTrace(Trace):
             except KeyError:
                 pass
             st[format][head_format] = val
-        if format == 'sh' and len(comment) > 0:
-            def default(obj):  # convert numpy types
-                return np.asscalar(obj)
-            st[format]['COMMENT'] = json.dumps(comment, separators=(',', ':'),
-                                               default=default)
+        if format == 'sh':
+            if sh_compat:
+                st[format].pop('COMMENT', None)
+            elif len(comment) > 0:
+                def default(obj):  # convert numpy types
+                    return np.asarray(obj).item()
+                st[format]['COMMENT'] = json.dumps(
+                    comment, separators=(',', ':'), default=default)
 
     def _seconds2utc(self, seconds, reftime=None):
         """Return UTCDateTime given as seconds relative to reftime"""
-        from collections import Iterable
+        from collections.abc import Iterable
         from obspy import UTCDateTime as UTC
         if isinstance(seconds, Iterable):
             return [self._seconds2utc(s, reftime=reftime) for s in seconds]
@@ -678,6 +686,8 @@ def rfstats(obj=None, event=None, station=None,
         return stream
     if dist_range == 'default' and phase.upper() in 'PS':
         dist_range = (30, 90) if phase.upper() == 'P' else (50, 85)
+    elif dist_range == 'default':
+        raise ValueError('Please specify dist_range parameter')
     stats = AttribDict({}) if obj is None else obj
     if event is not None and station is not None:
         stats.update(obj2stats(event=event, station=station))
@@ -695,7 +705,7 @@ def rfstats(obj=None, event=None, station=None,
                         (phase, dist))
     if len(arrivals) > 1:
         msg = ('TauPy returns more than one arrival for phase %s at '
-               'distance -> take first arrival')
+               'distance %s -> take first arrival')
         warnings.warn(msg % (phase, dist))
     arrival = arrivals[0]
     onset = stats.event_time + arrival.time
